@@ -4,9 +4,9 @@ package Random::Skew;
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
-our $GRAIN = 24; # default
+our $GRAIN = 72; # default
 sub GRAIN {
     if ( @_ ) {
         my $grain = shift( @_ );
@@ -214,19 +214,19 @@ Random::Skew - Set up a pool of items to return one of, randomly -- with some mo
   Random::Skew::ROUNDING( 0.5 );
 
   my $rs = Random::Skew->new(
-    # Populations in millionms (taken from Wikipedia, June 2023)
-    China  => 1411, # China will show up most often with the highest probability
-    India  => 1392,
-    USA    =>  334,
-    UK     =>   67,
-    Greece =>   10,
-    Panama =>    4,
-    Estonia=>    1, # rare, but always possible
+    # Populations (taken from Wikipedia, July 2023)
+    China  => 1_411_750_000, # China will show up most often
+    India  => 1_392_329_000,
+    USA    =>   335_016_000,
+    Russia =>   146_424_729,
+    UK     =>    67_026_292,
+    Panama =>     4_278_500,
+    Monaco =>        39_150, # rare, but still possible
   );
 
   # Now iterate a million times, generating a random country
-  for ( my $ix = 0 ; $ix <= 1_000_000 ; $ix++  ) {
-      my $ctry = $rs->item(); # probably China, but could even be Estonia
+  for ( my $ix = 1 ; $ix <= 1_000_000 ; $ix++  ) {
+      my $ctry = $rs->item(); # probably China, but might be Monaco
       ...
   }
 
@@ -237,35 +237,40 @@ first set up a pool of weighted random items to choose from, and then
 return one of those items at random. The relative weighting determines
 how likely any particular item is returned.
 
-Instead of this memory hog:
-  my @setup = (('Dog') x 999, ('Cat') x 234, ('Parrot') x 79, ('Octopus') x 1);
+Imagine this monstrous memory hog:
+
+  my @setup = (('Dog') x 76_000_000,
+               ('Cat') x 58_000_000,
+               ('Parrot') x 500_000,
+               ('Octopus') x    125);
   my $pet = $setup[ rand( @setup ) ];
 
-We do this:
+Instead, we do this:
+
   # Household Pets:
   my $random_pet = Random::Skew->new(
     # item => weight,
-    Dog    => 999,
-    Cat    => 234,
-    Parrot => 79,
-    Octopus=> 1,
+    Dog    => 76_000_000,
+    Cat    => 58_000_000,
+    Parrot =>    500_000,
+    Octopus=>        125,
   );
   my $pet = $random_pet->item; # Probably Dog, but could be Octopus
 
-In the above example, "Dog" is (roughly) 999 times as likely to show up
-as "Octopus" is. "Cat" is 234 times as likely, and "Parrot" is 79 times
-as likely. The percentages actually returned during a million-iteration
-run, might deviate a bit from the requested weightings, but not by much.
+In the above example, "Dog" is waaay more likely to show up than "Octopus"
+is. "Cat" is more likely than "Parrot" but less likely than "Dog". The
+percentages actually returned during a million-iteration run, might deviate
+a bit from the requested weightings, due to rounding, but not by much.
 
 The higher the relative 'weight' the more likely that item will appear
-in the result.  The lower the relative 'weight' the less likely.
+in the result. The lower the relative 'weight' the less likely.
 
 You can also generate a bunch in one go using the items() method:
 
-  my @stuff = $rs->item( 200 );
+  my @stuff = $rs->items( 200 );
 
-For reasonably simple hierarchical data, you could try complex hash
-keys:
+For reasonably simple hierarchical data, one approach could be to
+try complex hash keys:
 
   my $random_loc = Random::Skew->new(
     'CA:Los Angeles'   =>10000,
@@ -319,14 +324,17 @@ Generates C<$count> items and returns them in a list/array.
 =item Random::Skew::GRAIN( $int )
 
 Sets up maximum number-of-buckets for simulating the randomness
-you're shooting for, for the next C<<Random::Skew->new()>> object 
-you create. If your percentages are off, try different values here.
-Often larger numbers work well, at the expense of memory -- and
-sometimes prime numbers set up an amazingly close approximation.
+you're shooting for, for the next C<< Random::Skew->new() >> object 
+you create. It has no effect at all on existing L<Random::Skew> objects.
+
+If your percentages (from generating a large number of items) are off a
+bit, try different values here. Explore larger or smaller numbers;
+sometimes prime numbers work well, other times an integer with lots
+of factors can provide a better approximation.
 
 See L<Random::Skew::Test> for how to explore C<GRAIN()> values.
 
-Default C<Random::Skew::GRAIN> is 24.
+Default C<Random::Skew::GRAIN> is 72.
 
 =item Random::Skew::ROUNDING( $fraction )
 
@@ -522,8 +530,8 @@ hand, it would be difficult to represent that faithfully with a
 grain of 4 or 5. You'd get rounding issues and some items would
 return more often than expected, others less often than expected.
 
-Sometimes a larger grain (2500) works well, other times a
-smaller grain (13 for example) does better, with recursion.
+Sometimes a larger grain (2500 for example) works well, other times
+a smaller grain (13 for example) does better, with recursion.
 
 =head1 SEE ALSO
 
